==> kazehakase_0.2.8.orig.tar.gz: kazehakase-0.2.8.orig/src/mozilla/MozillaPrivate.h <==
/*
 *  Copyright (C) 2004 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: MozillaPrivate.h,v 1.6 2005/06/27 23:34:14 ikezoe Exp $
 */

/*
 * Based on MozillaPrivate.cpp in Epiphany-1.5.1.
 *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
 */

#ifndef __MOZILLA_PRIVATE_H__
#define __MOZILLA_PRIVATE_H__

#include <glib.h>
#include <gtk/gtk.h>
#include <nsIPrintSettings.h>
#include <nsIDOMWindow.h>
#include <nsIDOMDocument.h>
#include <nsIDOMRange.h>
#include <nsISelection.h>
#include <nsIDocShell.h>
#include <nsIBaseWindow.h>
#include <nsIDOMEventReceiver.h>
#include <nsIPref.h>

namespace MozillaPrivate
{
	GList    *GetPrinterList      ();
	gboolean  CreatePrintSettings (nsIPrintSettings **options);
	gboolean  GetRootRange        (nsIDOMDocument *domDoc, nsIDOMRange *range);
	gboolean  GetSelectedRange    (nsIDOMDocument *domDoc, nsIDOMRange *range,
				       nsISelection *selection, gboolean backward);
	gboolean  SetZoomOnDocShell   (float aZoom, nsIDocShell *DocShell);
	GdkWindow *GetGdkWindow       (nsIBaseWindow *window);
	gboolean  GetEventReceiver    (nsIDOMWindow *domWindow, nsIDOMEventReceiver **receiver);
	gchar    *GetURIForDOMWindow  (nsIDOMWindow *aDOMWindow);
}

class MozillaEmbedPrivate {
	public:
	MozillaEmbedPrivate();
  	~MozillaEmbedPrivate();
  	static nsIPref                *sPrefs;
  	static void *sProfileDirServiceProvider;

  	static nsresult StartupProfile (const char *sProfileDir, const char *sProfileName);
  	static void     ShutdownProfile(void);
};

#endif /* __MOZILLA_PRIVATE_H__ */

==> kazehakase-0.3.0.tar.gz: kazehakase-0.3.0/src/mozilla/MozillaPrivate.h <==
/*
 *  Copyright (C) 2004 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: MozillaPrivate.h,v 1.8 2005/07/22 08:06:36 ikezoe Exp $
 */

/*
 * Based on MozillaPrivate.cpp in Epiphany-1.5.1.
 *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
 */

#ifndef __MOZILLA_PRIVATE_H__
#define __MOZILLA_PRIVATE_H__

#include <glib.h>
#include <gtk/gtk.h>
#define MOZILLA_INTERNAL_API
#include <nsIPrintSettings.h>
#include <nsIDOMWindow.h>
#include <nsIDOMDocument.h>
#include <nsIDOMRange.h>
#include <nsISelection.h>
#include <nsIDocShell.h>
#include <nsIBaseWindow.h>
#include <nsIDOMEventReceiver.h>
#undef MOZILLA_INTERNAL_API

namespace MozillaPrivate
{
	GList    *GetPrinterList      ();
	gboolean  CreatePrintSettings (nsIPrintSettings **options);
	gboolean  GetRootRange        (nsIDOMDocument *domDoc, nsIDOMRange *range);
	gboolean  GetSelectedRange    (nsIDOMDocument *domDoc, nsIDOMRange *range,
				       nsISelection *selection, gboolean backward);
	gboolean  SetZoomOnDocShell   (float aZoom, nsIDocShell *DocShell);
	GdkWindow *GetGdkWindow       (nsIBaseWindow *window);
	gboolean  GetEventReceiver    (nsIDOMWindow *domWindow, nsIDOMEventReceiver **receiver);
	gchar    *GetURIForDOMWindow  (nsIDOMWindow *aDOMWindow);
}
#endif /* __MOZILLA_PRIVATE_H__ */
